<?php

/**
 * This file is part of ILIAS, a powerful learning management system
 * published by ILIAS open source e-Learning e.V.
 *
 * ILIAS is licensed with the GPL-3.0,
 * see https://www.gnu.org/licenses/gpl-3.0.en.html
 * You should have received a copy of said license along with the
 * source code, too.
 *
 * If this is not the case or you just want to try ILIAS, you'll find
 * us at:
 * https://www.ilias.de
 * https://github.com/ILIAS-eLearning
 *
 *********************************************************************/

declare(strict_types=1);

use ILIAS\DI\Container;

/**
 * @ilCtrl_IsCalledBy ilPlagScanExerciseConfigGUI: ilObjComponentSettingsGUI
 */
class ilPlagScanExerciseConfigGUI extends ilPluginConfigGUI
{
    protected Container $dic;
    protected ilPlagScanExercisePlugin $plugin;
    protected ilSetting $settings;

    public function __construct()
    {
        global $DIC;

        $this->dic = $DIC;
        $this->plugin = ilPlagScanExercisePlugin::getInstance();
        $this->settings = new ilSetting('psx');
    }

    public function executeCommand(): void
    {
        $next_class = $this->dic->ctrl()->getNextClass();
        if ($next_class === 'ilpropertyformgui') {
            $this->dic->ctrl()->forwardCommand($this->getSettingsForm());
        }
        parent::executeCommand();

    }

    public function performCommand(string $cmd): void
    {
        $this->buildTabs();
        $this->dic->tabs()->activateTab('settings');
        switch (strtolower($cmd)) {
            case 'save':
                $this->save();
                break;
            case 'configure':
            default:
                $this->showSettingsForm();
                break;
        }
    }

    protected function buildTabs(): void
    {
        $this->dic->tabs()->addTab(
            'settings',
            $this->plugin->txt('settings'),
            $this->dic->ctrl()->getLinkTarget($this, 'configure')
        );
    }

    public function getSettingsForm(): ilPropertyFormGUI
    {
        $form = new ilPropertyFormGUI();

        $form->setFormAction($this->dic->ctrl()->getFormAction($this));
        $form->setTitle($this->plugin->txt('settings'));
        $form->addCommandButton('save', $this->dic->language()->txt('save'));

        $server = new ilTextInputGUI($this->plugin->txt('set_server'), 'psx_server');
        $server->setValue($this->settings->get('psx_server', 'https://api.plagscan.com/'));
        $form->addItem($server);

        $client_id = new ilTextInputGUI($this->plugin->txt('set_clientid'), 'psx_clientid');
        $client_id->setValue($this->settings->get('psx_clientid', ''));
        $form->addItem($client_id);

        $api_key = new ilTextInputGUI($this->plugin->txt('set_apikey'), 'psx_apikey');
        $api_key->setValue($this->settings->get('psx_apikey', ''));
        $form->addItem($api_key);

        $language_selector = new ilSelectInputGUI($this->plugin->txt('set_lang'), 'psx_lang');
        $language_selector->setOptions(['english' => 'I am a poor little dropdown that wants meaningful options.']);
        $language_selector->setValue($this->settings->get('psx_lang'));
        $form->addItem($language_selector);

        $email_policy = new ilSelectInputGUI($this->plugin->txt('set_email'), 'psx_email');
        $email_policy->setOptions(
            [
                'no_mails' => $this->plugin->txt('set_emp_none'),
                'mail_all' => $this->plugin->txt('set_emp_all'),
                'mail_red' => $this->plugin->txt('set_emp_red'),
            ]
        );
        $email_policy->setValue($this->settings->get('psx_email', 'no_mails'));
        $form->addItem($email_policy);

        $chk_web = new ilCheckboxInputGUI($this->plugin->txt('set_chk_web'), 'psx_chk_web');
        $chk_web->setChecked($this->settings->get('psx_chk_web') === '1');
        $form->addItem($chk_web);

        $chk_my = new ilCheckboxInputGUI($this->plugin->txt('set_chk_my'), 'psx_chk_my');
        $chk_my->setChecked($this->settings->get('psx_chk_my') === '1');
        $form->addItem($chk_my);

        $chk_repo = new ilCheckboxInputGUI($this->plugin->txt('set_chk_repo'), 'psx_chk_repo');
        $chk_repo->setChecked($this->settings->get('psx_chk_repo') === '1');
        $form->addItem($chk_repo);

        $chk_orgrepo = new ilCheckboxInputGUI($this->plugin->txt('set_chk_orgrepo'), 'psx_chk_orgrepo');
        $chk_orgrepo->setChecked($this->settings->get('psx_chk_orgrepo') === '1');
        $form->addItem($chk_orgrepo);

        $chk_prev = new ilCheckboxInputGUI($this->plugin->txt('set_chk_prev'), 'psx_chk_prev');
        $chk_prev->setChecked($this->settings->get('psx_chk_prev') === '1');
        $form->addItem($chk_prev);

        $student_refusal = new ilCheckboxInputGUI($this->plugin->txt('set_refusal'), 'psx_refusal');
        $student_refusal->setChecked($this->settings->get('psx_refusal') === '1');
        $form->addItem($student_refusal);

        $student_disclosure = new ilTextAreaInputGUI($this->plugin->txt('set_disclosure'), 'psx_disclosure');
        $student_disclosure->setRows(10);
        $student_disclosure->setValue($this->settings->get('psx_disclosure', ''));
        $form->addItem($student_disclosure);

        $storage_limit = new ilSelectInputGUI($this->plugin->txt('set_storage'), 'psx_storage');
        $storage_limit->setOptions(
            [
                '1_week' => $this->plugin->txt('set_sto_week'),
                '3_months' => $this->plugin->txt('set_sto_3months'),
                '6_months' => $this->plugin->txt('set_sto_6months'),
                'never' => $this->plugin->txt('set_sto_never'),
            ]
        );
        $storage_limit->setValue($this->settings->get('psx_storage', '6_months'));
        $form->addItem($storage_limit);

        $sensitity = new ilSelectInputGUI($this->plugin->txt('set_sensitivity'), 'psx_sensitivity');
        $sensitity->setOptions(
            [
                'low' => $this->plugin->txt('set_sens_low'),
                'medium' => $this->plugin->txt('set_sens_medium'),
                'high' => $this->plugin->txt('set_sens_high'),
            ]
        );
        $sensitity->setValue($this->settings->get('psx_sensitivity', 'low'));
        $form->addItem($sensitity);

        $admin_mail = new ilEMailInputGUI($this->plugin->txt('set_adminmail'), 'psx_adminmail');
        $admin_mail->setValue($this->settings->get('psx_adminmail', ''));
        $form->addItem($admin_mail);

        return $form;
    }

    public function showSettingsForm(): void
    {
        $form = $this->getSettingsForm();
        $this->dic->ui()->mainTemplate()->setContent($form->getHTML());
    }

    public function save(): void
    {
        $form = $this->getSettingsForm();
        if ($form->checkInput()) {
            foreach ($this->dic->http()->request()->getParsedBody() as $post_data_key => $post_data_value) {
                if ($post_data_key === 'cmd') {
                    continue;
                }

                if ($post_data_value . $post_data_key === '') {
                    continue;
                }

                if (is_array($post_data_value)) {
                    $post_data_value = implode(',', $post_data_value);
                }

                $this->settings->set($post_data_key, $post_data_value);
            }
            $this->dic->ctrl()->redirect($this, 'configure');
        } else {
            $form->setValuesByPost();
            $this->dic->ui()->mainTemplate()->setContent($form->getHTML());
        }
    }
}
