<?php

/**
 * This file is part of ILIAS, a powerful learning management system
 * published by ILIAS open source e-Learning e.V.
 *
 * ILIAS is licensed with the GPL-3.0,
 * see https://www.gnu.org/licenses/gpl-3.0.en.html
 * You should have received a copy of said license along with the
 * source code, too.
 *
 * If this is not the case or you just want to try ILIAS, you'll find
 * us at:
 * https://www.ilias.de
 * https://github.com/ILIAS-eLearning
 *
 *********************************************************************/

declare(strict_types=1);

namespace PlagScan\Helper;

class Users extends Base
{
    /**
     * @return array|string
     */
    public function getAll(int $start = 0, int $limit = 0)
    {
        $data = [];
        if ($start) {
            $data['start'] = $start;
        }
        if ($limit) {
            $data['limit'] = $limit;
        }

        return $this->handler->request('users', 'GET', $this->access_token, $data);
    }

    /**
     * @return array|string
     */
    public function get(int $user_id)
    {
        return $this->handler->request('users/' . $user_id, 'GET', $this->access_token);
    }

    /**
     * @return array|string
     */
    public function add(string $username, string $firstname, string $lastname, string $email, int $group = 0)
    {
        $data = [
            'username' => $username,
            'firstname' => $firstname,
            'lastname' => $lastname,
            'email' => $email
        ];

        if ($group !== 0) {
            $data['deptID'] = $group;
        }

        return $this->handler->request('users', 'POST', $this->access_token, $data);
    }

    /**
     * @return array|string
     */
    public function changeProperties(int $user_id, array $changes)
    {
        return $this->handler->request('users/' . $user_id, 'PATCH', $this->access_token, $changes);
    }

    /**
     * @return array|string
     */
    public function delete(int $user_id)
    {
        return $this->handler->request('users/' . $user_id, 'DELETE', $this->access_token);
    }

    /**
     * @return array|string
     */
    public function getDocuments(int $user_id, string $shared = 'withMe', int $start = 0, int $limit = 0, int $mode = 0)
    {
        $data['shared'] = $shared;
        if ($start) {
            $data['start'] = $start;
        }
        if ($limit) {
            $data['limit'] = $limit;
        }
        if ($mode) {
            $data['mode'] = $mode;
        }
        return $this->handler->request('users/' . $user_id . '/documents', 'GET', $this->access_token, $data);
    }

    /**
     * @return array|string
     */
    public function archiveDocuments(int $user_id)
    {
        return $this->handler->request('users/' . $user_id . '/documents/archive', 'PUT', $this->access_token);
    }

    /**
     * @return array|string
     */
    public function getRepositoryDocuments(int $user_id, int $start = 0, int $limit = 0)
    {
        $data = [];
        if ($start) {
            $data['start'] = $start;
        }
        if ($limit) {
            $data['limit'] = $limit;
        }

        return $this->handler->request('users/' . $user_id . '/repository/documents', 'GET', $this->access_token, $data);
    }
}
